@@ -69,7 +69,7 @@ static GList *g_connections = NULL;     /* All open connections */
 static gint g_socket = -1;              /* Socket we're listening on */
 static GIOChannel *g_iochannel = NULL;  /* IO channel for above */
 static gint g_iochannel_tag = 0;        /* Event source tag for above */
-static char g_socket_name[MAXPATHLEN];  /* Name of socket we're listening on */
+static char *g_socket_name;             /* Name of socket we're listening on */
 
 struct _SeahorseAgentConn {
     gint stag;                  /* glib source tag */
@@ -93,12 +93,14 @@ struct _SeahorseAgentConn {
 #define ASS_OPTION  "OPTION"
 #define ASS_GETPASS "GET_PASSPHRASE"
 #define ASS_CLRPASS "CLEAR_PASSPHRASE"
+#define ASS_GETINFO "GETINFO"
 
 #define ASS_OPT_DISPLAY "display="
 
 /* Options */
 #define ASS_FLAG_DATA   "data"
 #define ASS_FLAG_CHECK  "check"
+#define ASS_FLAG_REPEAT "repeat"
 
 /* Responses */
 #define ASS_OK      "OK "
@@ -136,9 +138,8 @@ seahorse_agent_io_socket ()
     g_assert (g_socket == -1);
 
     /* We build put the socket in a directory called /tmp/seahorse-XXXXXX */
-    t = g_build_filename (g_get_tmp_dir (), SOCKET_DIR, NULL);
-    strncpy (g_socket_name, t, KL (g_socket_name));
-    g_free (t);
+    g_free (g_socket_name);
+    g_socket_name = g_build_filename (g_get_tmp_dir (), SOCKET_DIR, NULL);
 
     /* Make the appropriate directory */
     if (!mkdtemp (g_socket_name)) {
@@ -152,8 +153,9 @@ seahorse_agent_io_socket ()
         g_warning ("couldn't set permissions on directory: %s", strerror (errno));
 
     /* Build the socket name */
-    strncat (g_socket_name, SOCKET_FILE, KL (g_socket_name));
-    g_socket_name[KL (g_socket_name)] = 0;
+    t = g_socket_name;
+    g_socket_name = g_strdup_printf ("%s%s", g_socket_name, SOCKET_FILE);
+    g_free (t);
 
     memset (&addr, 0, sizeof (addr));
     addr.sun_family = AF_UNIX;
@@ -269,8 +271,21 @@ static guint32
 parse_assuan_flag (gchar *flag)
 {
     g_assert (flag);
-    if (g_str_equal (flag, "data"))
+    if (g_str_equal (flag, ASS_FLAG_DATA))
         return SEAHORSE_AGENT_PASS_AS_DATA;
+    else if (g_str_has_prefix (flag, ASS_FLAG_REPEAT)) {
+        gint count = 1;
+
+        flag += strlen(ASS_FLAG_REPEAT);
+        if (*flag == '=') {
+            count = atoi (++flag);
+            if (!(count == 0 || count == 1))
+                g_warning ("--repeat=%d treated as --repeat=1", count);
+        }
+
+        if (count)
+            return SEAHORSE_AGENT_REPEAT;
+    }
     return 0;
 }
 
@@ -373,6 +388,68 @@ x11_displays_eq (const gchar *d1, const gchar *d2)
     return (g_ascii_strncasecmp (d1, d2, l1 > l2 ? l1 : l2) == 0);
 }
 
+/* Does command have option? */
+static gboolean
+command_has_option (SeahorseAgentConn *cn, gchar * command, gchar * option)
+{
+    gboolean has_option = FALSE;
+
+    if (!strcmp (command, ASS_GETPASS)) {
+        has_option = (!strcmp (option, ASS_FLAG_DATA) ||
+                      !strcmp (option, ASS_FLAG_REPEAT));
+    }
+    /* else if (other commands) */
+
+    if (has_option)
+        seahorse_agent_io_reply (cn, TRUE, NULL);
+
+    return has_option;
+}
+
+/* Process a GETINFO request */
+static void
+ass_getinfo (SeahorseAgentConn *cn, gchar * request)
+{
+    gchar *args;
+    gboolean implemented = FALSE;
+
+    args = strchr (request, ' ');
+    if (args) {
+        *args = 0;
+        args++;
+        while (isspace (*args))
+            args++;
+    }
+
+    if (!strcmp (request, "cmd_has_option")) {
+        gchar *command = args;
+        gchar *option;
+
+        if (!command || !*command) {
+            seahorse_agent_io_reply (cn, FALSE, "105 parameter error");
+            return;
+        }
+
+        option = strchr(args, ' ');
+
+        if (option) {
+            *option = 0;
+            option++;
+            while (isspace (*option))
+                option++;
+        } else {
+            seahorse_agent_io_reply (cn, FALSE, "105 parameter error");
+            return;
+        }
+
+        implemented = command_has_option(cn, command, option);
+    }
+    /* else if (other info request) */
+
+    if (!implemented)
+        seahorse_agent_io_reply (cn, FALSE, "100 not implemented");
+}
+
 /* Process a request line from client */
 static void
 process_line (SeahorseAgentConn *cn, gchar *string)
@@ -484,6 +561,10 @@ process_line (SeahorseAgentConn *cn, gchar *string)
         seahorse_agent_actions_clrpass (cn, id);
     }
 
+    else if (strcasecmp (string, ASS_GETINFO) == 0) {
+        ass_getinfo (cn, args);
+    }
+
     else if (strcasecmp (string, ASS_NOP) == 0) {
         seahorse_agent_io_reply (cn, TRUE, NULL);
     }
@@ -729,16 +810,19 @@ seahorse_agent_io_uninit ()
 
         g_clear_error (&err);
 
-        /* Remove the socket */
-        unlink (g_socket_name);
+        if (g_socket_name) {
+            /* Remove the socket */
+            unlink (g_socket_name);
 
-        /* Remove the directory */
-        t = strrchr (g_socket_name, '/');
-        if (t != NULL) {
-            *t = 0;
-            rmdir (g_socket_name);
+            /* Remove the directory */
+            t = strrchr (g_socket_name, '/');
+            if (t != NULL) {
+                *t = 0;
+                rmdir (g_socket_name);
+            }
+
+            g_free (g_socket_name);
+            g_socket_name = NULL;
         }
-
-        g_socket_name[0] = 0;
     }    
 }
