@@ -275,7 +275,7 @@ create_auth_window (SeahorseAgentPassReq *pr)
     gtk_container_add (GTK_CONTAINER (bbox), w);
     g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (auth_cancel_button), pr);
 
-    GTK_WIDGET_SET_FLAGS (w, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (w, TRUE);
 
     w = gtk_button_new_from_stock (GTK_STOCK_OK);
     gtk_button_set_label (GTK_BUTTON (w), _("_Authorize"));
@@ -283,13 +283,13 @@ create_auth_window (SeahorseAgentPassReq *pr)
     gtk_container_add (GTK_CONTAINER (bbox), w);
 
     g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (auth_ok_button), pr);
-    GTK_WIDGET_SET_FLAGS (w, GTK_CAN_DEFAULT);
+    gtk_widget_set_can_default (w, TRUE);
     gtk_widget_grab_default (w);
 
     gtk_window_set_position (GTK_WINDOW (win), GTK_WIN_POS_CENTER);
     gtk_window_set_keep_above(GTK_WINDOW (win), TRUE);
     gtk_widget_show_all (win);
-    gdk_window_focus (win->window, GDK_CURRENT_TIME);
+    gdk_window_focus (gtk_widget_get_window (win), GDK_CURRENT_TIME);
     return win;
 }
 
