@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: seahorse-extension.c 2498 2008-09-13 22:13:48Z nnielsen $
+ *  $Id$
  */
 
 #include "config.h"
@@ -31,10 +31,7 @@
 #include "ephy-debug.h"
 
 #include <gmodule.h>
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkmenuitem.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -603,44 +600,22 @@ build_ui (WindowData *data)
 }
 
 
-#if EPHY_NOTAB == 1
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-#else
-static void
-impl_attach_tab (EphyExtension *extension,
-		 EphyWindow *window,
-		 EphyTab *tab)
-{
-	EphyEmbed *embed;
-
-	embed = ephy_tab_get_embed (tab);
-#endif
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_connect (embed, "ge_context_menu",
 			  G_CALLBACK (context_menu_cb), window);
 }
 
-#if EPHY_NOTAB == 1
 static void
 impl_detach_tab (EphyExtension *extension,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-#else
-static void
-impl_detach_tab (EphyExtension *extension,
-		 EphyWindow *window,
-		 EphyTab *tab)
-{
-	EphyEmbed *embed;
-
-	embed = ephy_tab_get_embed (tab);
-#endif
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_handlers_disconnect_by_func
